# -*- coding: utf-8 -*-

__author__ = 'Robbert Harms'
__date__ = '2019-01-28'
__email__ = 'robbert.harms@maastrichtuniversity.nl'
__license__ = "LGPL v3"
__maintainer__ = "Robbert Harms"

from .__version__ import VERSION, VERSION_STATUS, __version__
